import re

from markdown_it import MarkdownIt
from markdown_it.rules_inline import StateInline

LINK_PATTERN = re.compile(r"\[\[([^[|\]\n])+(\|[^]\n]+)?]]")


def _wikilink_inline(state: StateInline, silent: bool) -> bool:
    match = LINK_PATTERN.match(state.src[state.pos :])
    if not match:
        return False

    token = state.push("wikilink", "", 0)
    token.content = match.group()

    state.pos += match.end()

    return True


def wikilink_plugin(md: MarkdownIt) -> None:
    md.inline.ruler.push("wikilink", _wikilink_inline)



from typing import Mapping

from markdown_it import MarkdownIt
from mdformat.renderer import RenderContext, RenderTreeNode
from mdformat.renderer.typing import Render

from mdformat_wikilink.mdit_wikilink_plugin import wikilink_plugin


def update_mdit(mdit: MarkdownIt) -> None:
    mdit.use(wikilink_plugin)


def _render_wikilink(node: RenderTreeNode, context: RenderContext) -> str:
    return node.content


RENDERERS: Mapping[str, Render] = {"wikilink": _render_wikilink}
